==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/elemental/FireElementalEntity.java <==
package cc.thonly.reverie_dreams.entity.elemental;

import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.entity.skin.MobSkins;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1321;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1376;
import net.minecraft.class_1386;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1439;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_3218;
import net.minecraft.class_3612;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_8109;
import net.minecraft.entity.ai.goal.*;

public class FireElementalEntity extends NPCEntityImpl implements ElementalMob {
    public int aTick = 10;

    public FireElementalEntity(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world, MobSkins.FIRE_ELEMENTAL.get());
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1386(this));

        this.field_6201.method_6277(7, new class_1341(this, 1.0));
        this.field_6201.method_6277(8, new class_1394(this, 1.0));

        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 16.0f));
        this.field_6201.method_6277(10, new class_1361(this, NPCEntityImpl.class, 8.0f));
        this.field_6201.method_6277(10, new class_1376(this));

        this.field_6185.method_6277(2, new class_1400<>(this, class_1657.class, false));
        this.field_6185.method_6277(3, new class_1400<>(this, class_1439.class, false));
        this.field_6185.method_6277(3, new class_1399(this).method_6318());
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        class_8109 damageSources = world.method_48963();
        if (source.method_48792().equals(damageSources.method_48794().method_48792())) {
            return false;
        }
        return super.method_64397(world, source, amount);
    }

    @Override
    public void method_5773() {
        super.method_5773();
        class_1937 world = this.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            this.method_6092(new class_1293(class_1294.field_5918, 3 * 20));
            this.method_20803(20);
            if (this.aTick > 10) {
                boolean bl1 = this.method_5799();
                boolean bl2 = serverWorld.method_8316(this.method_24515()).method_39360(class_3612.field_15908) ||
                        serverWorld.method_8320(this.method_24515()).method_27852(class_2246.field_10036);

                if (bl1) {
                    this.method_6092(new class_1293(class_1294.field_5920, 3 * 20));
                    this.method_6092(new class_1293(class_1294.field_5899, 3 * 20));
                }
                if (bl2) {
                    this.method_6092(new class_1293(class_1294.field_5904, 3 * 20));
                    this.method_6092(new class_1293(class_1294.field_5900, 3 * 20));
                    this.method_6092(new class_1293(class_1294.field_5924, 3 * 20));
                }
                this.aTick = -1;
            }

            this.aTick++;
        }
    }

    @Override
    public boolean method_6121(class_3218 world, class_1297 target) {
        if (target instanceof class_1309) {
            target.method_20803(20 * 6);
        }
        return super.method_6121(world, target);
    }

    public static class_5132 createAttributes() {
        return class_1309.method_26827()
                .method_26868(class_5134.field_23716, 40.0)
                .method_26868(class_5134.field_23719, 0.22)
                .method_26868(class_5134.field_23722, 0.25)
                .method_26868(class_5134.field_23721, 3.5)
                .method_26868(class_5134.field_23718, 0.1)
                .method_26868(class_5134.field_23717, 32.0)
                .method_26868(class_5134.field_52450, 10.0)
                .method_26868(class_5134.field_47759, 3)
                .method_26866();
    }

    @Override
    public Boolean canPickItem() {
        return false;
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/elemental/FireElementalEntity.java <==
package cc.thonly.reverie_dreams.entity.elemental;

import cc.thonly.reverie_dreams.entity.interfaces.ElementalMob;
import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import cc.thonly.reverie_dreams.registry.content.skin.MobSkinTypes;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1321;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1376;
import net.minecraft.class_1386;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1439;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_3218;
import net.minecraft.class_3612;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_8109;

public class FireElementalEntity extends BaseNPCLikeEntity implements ElementalMob {
    public int aTick = 10;

    public FireElementalEntity(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world, MobSkinTypes.FIRE_ELEMENTAL);
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1386(this));

        this.field_6201.method_6277(7, new class_1341(this, 1.0));
        this.field_6201.method_6277(8, new class_1394(this, 1.0));

        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 16.0f));
        this.field_6201.method_6277(10, new class_1361(this, BaseNPCLikeEntity.class, 8.0f));
        this.field_6201.method_6277(10, new class_1376(this));

        this.field_6185.method_6277(2, new class_1400<>(this, class_1657.class, false));
        this.field_6185.method_6277(3, new class_1400<>(this, class_1439.class, false));
        this.field_6185.method_6277(3, new class_1399(this).method_6318());
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        class_8109 damageSources = world.method_48963();
        if (source.method_48792().equals(damageSources.method_48794().method_48792())) {
            return false;
        }
        return super.method_64397(world, source, amount);
    }

    @Override
    public void method_5773() {
        super.method_5773();
        class_1937 world = this.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            this.method_6092(new class_1293(class_1294.field_5918, 3 * 20));
            this.method_20803(20);
            if (this.aTick > 10) {
                boolean bl1 = this.method_5799();
                boolean bl2 = serverWorld.method_8316(this.method_24515()).method_39360(class_3612.field_15908) ||
                        serverWorld.method_8320(this.method_24515()).method_27852(class_2246.field_10036);

                if (bl1) {
                    this.method_6092(new class_1293(class_1294.field_5920, 3 * 20));
                    this.method_6092(new class_1293(class_1294.field_5899, 3 * 20));
                }
                if (bl2) {
                    this.method_6092(new class_1293(class_1294.field_5904, 3 * 20));
                    this.method_6092(new class_1293(class_1294.field_5900, 3 * 20));
                    this.method_6092(new class_1293(class_1294.field_5924, 3 * 20));
                }
                this.aTick = -1;
            }

            this.aTick++;
        }
    }

    @Override
    public boolean method_6121(class_3218 world, class_1297 target) {
        if (target instanceof class_1309) {
            target.method_20803(20 * 6);
        }
        return super.method_6121(world, target);
    }

    public static class_5132 createAttributes() {
        return class_1309.method_26827()
                .method_26868(class_5134.field_23716, 40.0)
                .method_26868(class_5134.field_23719, 0.22)
                .method_26868(class_5134.field_23722, 0.25)
                .method_26868(class_5134.field_23721, 3.5)
                .method_26868(class_5134.field_23718, 0.1)
                .method_26868(class_5134.field_23717, 32.0)
                .method_26868(class_5134.field_52450, 10.0)
                .method_26868(class_5134.field_47759, 3)
                .method_26866();
    }

    @Override
    public Boolean canPickItem() {
        return false;
    }
}
